@@ -11,7 +11,6 @@ from typing import ClassVar
 from uuid import uuid4
 
 import doit
-import tomli
 from beartype import beartype
 from beartype.typing import Any, Callable, Dict, Iterable, List, Optional, Pattern, Set, Tuple, Union
 from doit.action import BaseAction
@@ -25,6 +24,11 @@ from ..file_helpers import _MKDOCS_CONFIG_NAME, _read_yaml_file, get_doc_dir
 from ..file_search import find_project_files, find_project_files_by_suffix
 from ..log_helpers import log_fun
 
+try:
+    import tomllib
+except ModuleNotFoundError:
+    import tomli as tomllib  # type: ignore[no-redef]
+
 _DOIT_TASK_IMPORT_ERROR = 'User must install the optional calcipy extra "dev" to utilize "doit_tasks"'
 """Standard error message when an optional import is not available. Raise with RuntimeError."""
 
@@ -159,7 +163,7 @@ class PackageMeta(_PathAttrBase):
         if not self.path_toml.is_file():
             raise RuntimeError(f'Check "path_project". Could not find: "{self.path_toml}"')
 
-        poetry_config = tomli.loads(self.path_toml.read_text())['tool']['poetry']
+        poetry_config = tomllib.loads(self.path_toml.read_text())['tool']['poetry']
         self.pkg_name = poetry_config['name']
         self.pkg_version = poetry_config['version']
         py_constraint = poetry_config['dependencies']['python']
@@ -256,24 +260,9 @@ class TestingConfig(_PathAttrBase):  # pylint: disable=too-many-instance-attribu
     args_pytest: str = Field(default='--exitfirst --showlocals --failed-first --new-first --verbose')
     """Default arguments to Pytest"""
 
-    args_diff: str = Field(
-        default='--fail-under=50 --include-untracked --ignore-whitespace --show-uncovered --compare-branch=origin/main',
-    )
-    """Default arguments to diff-cover.
-
-    Note: this may need to overridden for projects that don't use a main branch or need a lower threshold
-
-    """
-
     path_test_report: ClassVar[Path]
     """Path to the self-contained test HTML report."""
 
-    path_diff_test_report: ClassVar[Path]
-    """Path to the self-contained diff-test HTML report."""
-
-    path_diff_lint_report: ClassVar[Path]
-    """Path to the self-contained diff-lint HTML report."""
-
     path_coverage_index: ClassVar[Path]
     """Path to the coverage HTML index file within the report directory."""
 
@@ -288,8 +277,6 @@ class TestingConfig(_PathAttrBase):  # pylint: disable=too-many-instance-attribu
         self.path_out.mkdir(exist_ok=True, parents=True)
         # Configure the paths to the report HTML and coverage HTML files
         self.path_test_report = self.path_out / 'test_report.html'
-        self.path_diff_test_report = self.path_out / 'diff_test_report.html'
-        self.path_diff_lint_report = self.path_out / 'diff_lint_report.html'
         self.path_coverage_index = self.path_out / 'cov_html/index.html'
         self.path_mypy_index = self.path_out / 'mypy_html/index.html'
 
@@ -445,7 +432,7 @@ def create_dg(*, path_project: Path) -> DoitGlobals:
     # Read the optional toml configuration
     # > Note: could allow LintConfig/.../DocConfig kwargs to be set in toml, but may be difficult to maintain
     data = (path_project / 'pyproject.toml').read_text()
-    calcipy_config = tomli.loads(data).get('tool', {}).get('calcipy', {})
+    calcipy_config = tomllib.loads(data).get('tool', {}).get('calcipy', {})
 
     meta = _set_meta(path_project, calcipy_config)
     kwargs = _set_submodules(meta, calcipy_config)
